==> 0.3.122.tar.gz: lib/message.dart <==
import 'package:flutter/foundation.dart';
import 'package:wowit/common.dart';
import 'package:wowit/sqlService.dart';

import 'methods.dart';

class Message {
//get message by key
  static String getMessage(String key) {
    if (Common.mapMessageData.containsKey(key)) {
      return Common.mapMessageData[key];
    }
    key = key.toUpperCase();
    if (Common.mapMessageData.containsKey(key)) {
      return Common.mapMessageData[key];
    }
    return key;
  }

  static void setLanguage(int languageCode) {
    Common.languageId = languageCode;
  }

  static String _presLanguage = "language";
  static String useMessageFromSever = "messageSever";

  static Future<void> getMessageSQL(dynamic prefs, VoidCallback showWatting,
      VoidCallback hideWatting, Map<String, String> defaultMessage,
      {bool reload = false, bool useMessageFromSever = false}) async {
    if(prefs.getBool(useMessageFromSever) != null || prefs.getBool(useMessageFromSever)){
      useMessageFromSever = prefs.getBool(useMessageFromSever);
    }
    if (!kReleaseMode && !useMessageFromSever) {
      print('getMessageSQL app run debug not get message from server');
      if(reload){
        Common.initWowIT(
        defaultMessage,
        Common.url_host,
      );
      }
    } else {
      final pattern =
          "[(=-|"; //cong key kho vao, de dam bao khong gap ky tu user su dung.

      int language = Common.languageId ?? 1;
      Map<String, String> valueMessage = Map();
      if (prefs.getStringList(_presLanguage) == null || reload) {
        if (reload) {
          showWatting.call();
        }
        List<String> listLanguage = [];
        var data = await SQLService.execute('getMessage',
            params: {'@languageId': language});
        if (Methods.getList(data, 'language').length > 200) {
          if (Common.uid > 0) {
            SQLService.execute('sp_setHasMapMessage',
                params: {'@uid': Common.uid});
          }

          for (var item in Methods.getList(data, 'language')) {
            listLanguage.add(Methods.getString(item, 'messageId') +
                pattern +
                Methods.getString(item, 'message'));
          }
          if (prefs.getStringList(_presLanguage) != null) {
            prefs.remove(_presLanguage);
          }
          prefs.setStringList(_presLanguage, listLanguage);

          for (var itemlist in prefs.getStringList(_presLanguage)) {
            var convert = itemlist.split(pattern);
            if (convert != null && convert.length > 1) {
              String messageId = convert[0].toString().toUpperCase();
              if (!valueMessage.containsKey(messageId)) {
                valueMessage[messageId] = convert[1];
              }
            }
          }
        } else {
          valueMessage = defaultMessage;
        }
      } else {
        for (var itemlist in prefs.getStringList(_presLanguage)) {
          var convert = itemlist.split(pattern);
          if (convert != null && convert.length > 1) {
            String messageId = convert[0].toString().toUpperCase();
            if (!valueMessage.containsKey(messageId)) {
              valueMessage[messageId] = convert[1];
            }
          }
        }
      }
      Common.initWowIT(
        valueMessage,
        Common.url_host,
      );
      if (reload) {
        hideWatting.call();
      }
    }
  }
}

==> 0.3.123.tar.gz: lib/message.dart <==
import 'package:flutter/foundation.dart';
import 'package:wowit/common.dart';
import 'package:wowit/sqlService.dart';

import 'methods.dart';

class Message {
//get message by key
  static String getMessage(String key) {
    if (Common.mapMessageData.containsKey(key)) {
      return Common.mapMessageData[key];
    }
    key = key.toUpperCase();
    if (Common.mapMessageData.containsKey(key)) {
      return Common.mapMessageData[key];
    }
    return key;
  }

  static void setLanguage(int languageCode) {
    Common.languageId = languageCode;
  }

  static String _presLanguage = "language";
  static String presUseMessageFromSever = "messageSever";

  static Future<void> getMessageSQL(dynamic prefs, VoidCallback showWatting,
      VoidCallback hideWatting, Map<String, String> defaultMessage,
      {bool reload = false, bool useMessageFromSever = false}) async {
    if(prefs.getBool(presUseMessageFromSever) != null || prefs.getBool(presUseMessageFromSever)){
      useMessageFromSever = prefs.getBool(presUseMessageFromSever);
    }
    if (!kReleaseMode && !useMessageFromSever) {
      print('getMessageSQL app run debug not get message from server');
      if(reload){
        Common.initWowIT(
        defaultMessage,
        Common.url_host,
      );
      }
    } else {
      final pattern =
          "[(=-|"; //cong key kho vao, de dam bao khong gap ky tu user su dung.

      int language = Common.languageId ?? 1;
      Map<String, String> valueMessage = Map();
      if (prefs.getStringList(_presLanguage) == null || reload) {
        if (reload) {
          showWatting.call();
        }
        List<String> listLanguage = [];
        var data = await SQLService.execute('getMessage',
            params: {'@languageId': language});
        if (Methods.getList(data, 'language').length > 200) {
          if (Common.uid > 0) {
            SQLService.execute('sp_setHasMapMessage',
                params: {'@uid': Common.uid});
          }

          for (var item in Methods.getList(data, 'language')) {
            listLanguage.add(Methods.getString(item, 'messageId') +
                pattern +
                Methods.getString(item, 'message'));
          }
          if (prefs.getStringList(_presLanguage) != null) {
            prefs.remove(_presLanguage);
          }
          prefs.setStringList(_presLanguage, listLanguage);

          for (var itemlist in prefs.getStringList(_presLanguage)) {
            var convert = itemlist.split(pattern);
            if (convert != null && convert.length > 1) {
              String messageId = convert[0].toString().toUpperCase();
              if (!valueMessage.containsKey(messageId)) {
                valueMessage[messageId] = convert[1];
              }
            }
          }
        } else {
          valueMessage = defaultMessage;
        }
      } else {
        for (var itemlist in prefs.getStringList(_presLanguage)) {
          var convert = itemlist.split(pattern);
          if (convert != null && convert.length > 1) {
            String messageId = convert[0].toString().toUpperCase();
            if (!valueMessage.containsKey(messageId)) {
              valueMessage[messageId] = convert[1];
            }
          }
        }
      }
      Common.initWowIT(
        valueMessage,
        Common.url_host,
      );
      if (reload) {
        hideWatting.call();
      }
    }
  }
}
